# Author: Toshio Kuratomi <tkuratom@redhat.com>
# License: GPLv3+
# Copyright: Ansible Project, 2020
"""Parse documentation from ansible plugins using ansible apis."""

def plugin_output_directory(plugin_type, output_dir):
    """
    Determine the output directory based on the plugin_type

    For backwards link compatibility, modules are in a toplevel modules directory while other
    plugins are in a subdirectory of plugins
    """
    if plugin_type in ('module', 'module_util'):
        return '%s/%ss' % (output_dir, plugin_type)
    return '%s/plugins/%s' % (output_dir, plugin_type)


def plugin_filename_format(plugin_type):
    """
    Determine the filename format string to use for this type of plugin

    For backwards link compatibility, modules use a format of ``<module>_module.rst``
    whereas other plugins just use ``<module>.rst``.
    """
    if plugin_type == 'module':
        output_name = '%s_' + '%s.rst' % plugin_type
    else:
        # for plugins, just use 'ssh.rst' vs 'ssh_module.rst'
        output_name = '%s.rst'

    return output_name


